cosmpy.protos.tendermint.types package — cosmpy documentation

# cosmpy.protos.tendermint.types package

## Submodules

## cosmpy.protos.tendermint.types.block_pb2 module

Generated protocol buffer code.

## cosmpy.protos.tendermint.types.block_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## cosmpy.protos.tendermint.types.evidence_pb2 module

Generated protocol buffer code.

## cosmpy.protos.tendermint.types.evidence_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## cosmpy.protos.tendermint.types.params_pb2 module

Generated protocol buffer code.

## cosmpy.protos.tendermint.types.params_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## cosmpy.protos.tendermint.types.types_pb2 module

Generated protocol buffer code.

## cosmpy.protos.tendermint.types.types_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## cosmpy.protos.tendermint.types.validator_pb2 module

Generated protocol buffer code.

## cosmpy.protos.tendermint.types.validator_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## Module contents